<?php

namespace Test\P1\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Test\P1\Http\Requests\Module1Request;
use Test\P1\Models\Module1;

/**
 * Admin web controller class.
 */
class Module1WorkflowController extends BaseController
{

    /**
     * Workflow controller function for module1.
     *
     * @param Model   $module1
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(Module1Request $request, Module1 $module1, $step)
    {

        try {

            $module1->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('p1::module1.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/module1/module1/' . $module1->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/module1/module1/' . $module1->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for module1.
     *
     * @param Model   $module1
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(Module1 $module1, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $module1->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('p1::module1.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('p1::admin.module1.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('p1::admin.module1.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('p1::admin.module1.message', $data)->render();

        }

    }
}
