<?php

namespace Test\P1\Policies;

use Litepie\User\Contracts\UserPolicy;
use Test\P1\Models\Module1;

class Module1Policy
{

    /**
     * Determine if the given user can view the module1.
     *
     * @param UserPolicy $user
     * @param Module1 $module1
     *
     * @return bool
     */
    public function view(UserPolicy $user, Module1 $module1)
    {
        if ($user->canDo('p1.module1.view') && $user->isAdmin()) {
            return true;
        }

        return $module1->user_id == user_id() && $module1->user_type == user_type();
    }

    /**
     * Determine if the given user can create a module1.
     *
     * @param UserPolicy $user
     * @param Module1 $module1
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('p1.module1.create');
    }

    /**
     * Determine if the given user can update the given module1.
     *
     * @param UserPolicy $user
     * @param Module1 $module1
     *
     * @return bool
     */
    public function update(UserPolicy $user, Module1 $module1)
    {
        if ($user->canDo('p1.module1.edit') && $user->isAdmin()) {
            return true;
        }

        return $module1->user_id == user_id() && $module1->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given module1.
     *
     * @param UserPolicy $user
     * @param Module1 $module1
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Module1 $module1)
    {
        return $module1->user_id == user_id() && $module1->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given module1.
     *
     * @param UserPolicy $user
     * @param Module1 $module1
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Module1 $module1)
    {
        if ($user->canDo('p1.module1.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given module1.
     *
     * @param UserPolicy $user
     * @param Module1 $module1
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Module1 $module1)
    {
        if ($user->canDo('p1.module1.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
