<?php

namespace Test\P1\Workflow;

use Test\P1\Models\Module1;
use Validator;

class Module1Validator
{

    /**
     * Determine if the given module1 is valid for complete status.
     *
     * @param Module1 $module1
     *
     * @return bool / Validator
     */
    public function complete(Module1 $module1)
    {
        return Validator::make($module1->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given module1 is valid for verify status.
     *
     * @param Module1 $module1
     *
     * @return bool / Validator
     */
    public function verify(Module1 $module1)
    {
        return Validator::make($module1->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given module1 is valid for approve status.
     *
     * @param Module1 $module1
     *
     * @return bool / Validator
     */
    public function approve(Module1 $module1)
    {
        return Validator::make($module1->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given module1 is valid for publish status.
     *
     * @param Module1 $module1
     *
     * @return bool / Validator
     */
    public function publish(Module1 $module1)
    {
        return Validator::make($module1->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given module1 is valid for archive status.
     *
     * @param Module1 $module1
     *
     * @return bool / Validator
     */
    public function archive(Module1 $module1)
    {
        return Validator::make($module1->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given module1 is valid for unpublish status.
     *
     * @param Module1 $module1
     *
     * @return bool / Validator
     */
    public function unpublish(Module1 $module1)
    {
        return Validator::make($module1->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
